==> digikam-3.0.0-beta1.tar.bz2: digikam-3.0.0-beta1/extra/kipi-plugins/galleryexport/kipiplugin_galleryexport.desktop.cmake <==
[Desktop Entry]
Name=Remote Gallery Export
Name[ast]=Exportador de galería remota
Name[bg]=Изнасяне към Gallery
Name[bs]=Izvoz u udaljenu galeriju
Name[ca]=Exportador a Gallery remot
Name[ca@valencia]=Remote Gallery Export
Name[cs]=Export do vzdálené galerie
Name[da]=Remote Gallery Export
Name[de]=Gallery-Export
Name[el]=Εξαγωγή σε απομακρυσμένη πινακοθήκη
Name[en_GB]=Remote Gallery Export
Name[es]=Exportar a Gallery
Name[et]=Võrgugalerii eksport
Name[eu]=Urruneko galeria esportatzea
Name[fi]=Etägalleriavienti
Name[fr]=Module externe pour l'export vers Gallery
Name[ga]=Easpórtáil Cianghailearaí
Name[gl]=Exportación a galerías remotas
Name[he]=יצוא לגלריה מרוחקת
Name[hne]=रिमोट गैलरी निर्यात
Name[hu]=Távoli galéria exportálás
Name[is]=Samstilling við fjarlæg myndasöfn
Name[it]=Esportazione a gallerie remote
Name[ja]=Remote Gallery Export
Name[km]=នាំចេញ​វិចិត្រសាល​ពី​ចម្ងាយ
Name[lv]=Eksportēt uz attālinātu galeriju
Name[nb]=Fjerngallerieksport
Name[nds]=Feern Sammeln exporteren
Name[nl]=Exporteren naar een galerij op afstand
Name[pa]=ਰਿਮੋਟ ਗੈਲਰੀ ਐਕਸਪੋਰਟ
Name[pl]=Eksport do zdalnej galerii
Name[pt]=Exportação para uma Galeria Remota
Name[pt_BR]=Exportar para o Gallery remoto
Name[ro]=Export către Gallery
Name[ru]=Экспорт в удалённую галерею
Name[sk]=Export do vzdialenej galérie
Name[sl]=Izvoz v oddaljeno galerijo
Name[sq]=Eksportim i Galerisë së Largët
Name[sv]=Export till fjärrgalleri
Name[th]=ส่งออกภาพต่าง ๆ ไปยังแกลเลอรีทางไกล
Name[tr]=Uzak Galeri Aktarma
Name[uk]=Експорт до віддаленого сервера Gallery
Name[x-test]=xxRemote Gallery Exportxx
Name[zh_CN]=远程 Gallery 导出
Name[zh_TW]=遠端 Gallery 匯出
Comment=A tool to export images to a remote Gallery
Comment[ast]=Una ferramienta pa esportar imáxenes a una galería remota
Comment[bg]=Инструмент за изнасяне на изображения към отдалечена уеб-услуга Gallery
Comment[bs]=Alat za izvoz slika u udaljenu galeriju
Comment[ca]=Una eina per exportar imatges a una galeria remota
Comment[ca@valencia]=Una eina per exportar imatges a una galeria remota
Comment[cs]=Nástroj pro export obrázků do vzdálené galerie
Comment[da]=Et værktøj til at eksportere billeder til et eksternt galleri
Comment[de]=Ein Werkzeug, um Bilder zu einer entfernten Gallery-Installation zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων σε μια απομακρυσμένη πινακοθήκη
Comment[en_GB]=A tool to export images to a remote Gallery
Comment[es]=Herramienta para exportar imágenes a Gallery
Comment[et]=Tööriist piltide eksportimiseks võrgugaleriisse
Comment[eu]=Urruneko galeriara irudiak esportatzeko tresna
Comment[fi]=Työkalu kuvien etägalleriaan viemiseen
Comment[fr]=Outil pour l'exportation vers Gallery
Comment[gl]=Unha ferramenta para exportar imaxes a unha galería remota
Comment[he]=כלי ליצוא תמונות לגלריה מרוחקת
Comment[hne]=रिमोट गैलरी मं फोटू ल निर्यात करे के एक औजार
Comment[hu]=Egy eszköz képek exportálásához egy távoli galériába
Comment[is]=Verkfæri til að senda myndir í fjarlæg myndasöfn
Comment[it]=Uno strumento per esportare immagini a una galleria remota
Comment[ja]=画像をリモートのギャラリーにエクスポートするツール
Comment[km]=ឧបករណ៍​​ត្រូវ​នាំរូបភាព​ចេញ​ទៅ​វិចិត្រ​សាល​ពី​ចម្ងាយ
Comment[lv]=Rīks attēlu eksportēšanai uz attālinātu galeriju
Comment[nb]=Et verktøy for å eksportere bilder til en fjern Gallery-tjener
Comment[nds]=En Warktüüch, mit dat Biller na en feern Galerie exporteren laat
Comment[nl]=Een hulpmiddel om afbeeldingen te exporteren naar een Galerij op afstand
Comment[pa]=ਇੱਕ ਰਿਮੋਟ ਗੈਲਰੀ ਲਈ ਚਿੱਤਰ ਐਕਸਪੋਰਟ ਕਰਨ ਵਾਸਤੇ ਇੱਕ ਟੂਲ
Comment[pl]=Narzędzie do eksportowania obrazów do zdalnej galerii
Comment[pt]=Uma ferramenta para exportar imagens para uma galeria remota
Comment[pt_BR]=Uma ferramenta para exportar imagens para o Gallery remoto
Comment[ro]=O unealtă de exportat imagini către Gallery
Comment[ru]=Инструмент для экспорта изображений в удалённую галерею
Comment[sk]=Nástroj na export obrázkov do vzdialenej galérie
Comment[sl]=Orodje za izvoz slik v oddaljeno galerijo
Comment[sq]=Një mjet për të eksportuar imazhet në një galeri të largët
Comment[sv]=Ett verktyg för att exportera bilder till ett fjärrgalleri
Comment[th]=เครื่องมือส่งออกภาพต่าง ๆ ไปยังแกลเลอรีทางไกล
Comment[tr]=Resimleri uzak bir Galeriye aktarmak için bir araç
Comment[uk]=Інструмент для експорту зображення до віддаленого сервера Gallery
Comment[x-test]=xxA tool to export images to a remote Galleryxx
Comment[zh_CN]=一个将图像导出到远程 Gallery 的工具
Comment[zh_TW]=匯出影像到遠端 Gallery 的工具
Type=Service
Icon=gallery
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_galleryexport
X-KIPI-PluginCategories=Export
author=Andrea Diamantini, adjam7@gmail.com

==> digikam-4.0.0-beta1.tar.bz2: digikam-4.0.0-beta1/extra/kipi-plugins/galleryexport/kipiplugin_galleryexport.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Remote Gallery Export
Name=Remote Gallery Export
Name[ast]=Exportador de galería remota
Name[bg]=Изнасяне към Gallery
Name[bs]=Izvoz u udaljenu galeriju
Name[ca]=Exportador a Gallery remot
Name[ca@valencia]=Exportador a Gallery remot
Name[cs]=Export do vzdálené galerie
Name[da]=Remote Gallery Export
Name[de]=Gallery-Export
Name[el]=Εξαγωγή σε απομακρυσμένη πινακοθήκη
Name[en_GB]=Remote Gallery Export
Name[es]=Exportar a Gallery
Name[et]=Võrgugalerii eksport
Name[eu]=Urruneko galeria esportatzea
Name[fi]=Etägalleriavienti
Name[fr]=Exportation vers une collection distante
Name[ga]=Easpórtáil Cianghailearaí
Name[gl]=Exportación a galerías remotas
Name[he]=יצוא לגלריה מרוחקת
Name[hne]=रिमोट गैलरी निर्यात
Name[hu]=Távoli galéria exportálás
Name[is]=Samstilling við fjarlæg myndasöfn
Name[it]=Esportazione a gallerie remote
Name[ja]=Remote Gallery Export
Name[km]=នាំចេញ​វិចិត្រសាល​ពី​ចម្ងាយ
Name[lt]=Nuotolinės galerijos eksportas
Name[lv]=Eksportēt uz attālinātu galeriju
Name[nb]=Fjerngallerieksport
Name[nds]=Feern Sammeln exporteren
Name[nl]=Exporteren naar een galerij op afstand
Name[pa]=ਰਿਮੋਟ ਗੈਲਰੀ ਐਕਸਪੋਰਟ
Name[pl]=Eksport do zdalnej galerii
Name[pt]=Exportação para uma Galeria Remota
Name[pt_BR]=Exportar para o Gallery remoto
Name[ro]=Export către Gallery
Name[ru]=Экспорт в удалённую галерею
Name[sk]=Export do vzdialenej galérie
Name[sl]=Izvoz v oddaljen strežnik Gallery
Name[sq]=Eksportim i Galerisë së Largët
Name[sv]=Export till fjärrgalleri
Name[th]=ส่งออกภาพต่าง ๆ ไปยังแกลเลอรีทางไกล
Name[tr]=Uzak Galeri Aktarma
Name[uk]=Експорт до віддаленого сервера Gallery
Name[x-test]=xxRemote Gallery Exportxx
Name[zh_CN]=远程 Gallery 导出
Name[zh_TW]=遠端 Gallery 匯出
Comment=A tool to export images to a remote Gallery
Comment[ast]=Una ferramienta pa esportar imáxenes a una galería remota
Comment[bg]=Инструмент за изнасяне на изображения към отдалечена уеб-услуга Gallery
Comment[bs]=Alat za izvoz slika u udaljenu galeriju
Comment[ca]=Una eina per exportar imatges a una galeria remota
Comment[ca@valencia]=Una eina per exportar imatges a una galeria remota
Comment[cs]=Nástroj pro export obrázků do vzdálené galerie
Comment[da]=Et værktøj til at eksportere billeder til et eksternt galleri
Comment[de]=Ein Werkzeug, um Bilder zu einer entfernten Gallery-Installation zu exportieren.
Comment[el]=Εργαλείο εξαγωγής εικόνων σε μια απομακρυσμένη πινακοθήκη
Comment[en_GB]=A tool to export images to a remote Gallery
Comment[es]=Herramienta para exportar imágenes a Gallery
Comment[et]=Tööriist piltide eksportimiseks võrgugaleriisse
Comment[eu]=Urruneko galeriara irudiak esportatzeko tresna
Comment[fi]=Työkalu kuvien etägalleriaan viemiseen
Comment[fr]=Outil pour l'exportation d'images vers une collection distante
Comment[gl]=Unha ferramenta para exportar imaxes a unha galería remota
Comment[he]=כלי ליצוא תמונות לגלריה מרוחקת
Comment[hne]=रिमोट गैलरी मं फोटू ल निर्यात करे के एक औजार
Comment[hu]=Egy eszköz képek exportálásához egy távoli galériába
Comment[is]=Verkfæri til að senda myndir í fjarlæg myndasöfn
Comment[it]=Uno strumento per esportare immagini a una galleria remota
Comment[ja]=画像をリモートのギャラリーにエクスポートするツール
Comment[km]=ឧបករណ៍​​ត្រូវ​នាំរូបភាព​ចេញ​ទៅ​វិចិត្រ​សាល​ពី​ចម្ងាយ
Comment[lv]=Rīks attēlu eksportēšanai uz attālinātu galeriju
Comment[nb]=Et verktøy for å eksportere bilder til en fjern Gallery-tjener
Comment[nds]=En Warktüüch, mit dat Biller na en feern Galerie exporteren laat
Comment[nl]=Een hulpmiddel om afbeeldingen te exporteren naar een Galerij op afstand
Comment[pa]=ਇੱਕ ਰਿਮੋਟ ਗੈਲਰੀ ਲਈ ਚਿੱਤਰ ਐਕਸਪੋਰਟ ਕਰਨ ਵਾਸਤੇ ਇੱਕ ਟੂਲ
Comment[pl]=Narzędzie do eksportowania obrazów do zdalnej galerii
Comment[pt]=Uma ferramenta para exportar imagens para uma galeria remota
Comment[pt_BR]=Uma ferramenta para exportar imagens para o Gallery remoto
Comment[ro]=O unealtă de exportat imagini către Gallery
Comment[ru]=Инструмент для экспорта изображений в удалённую галерею
Comment[sk]=Nástroj na export obrázkov do vzdialenej galérie
Comment[sl]=Orodje za izvoz slik v oddaljen strežnik Gallery
Comment[sq]=Një mjet për të eksportuar imazhet në një galeri të largët
Comment[sv]=Ett verktyg för att exportera bilder till ett fjärrgalleri
Comment[th]=เครื่องมือส่งออกภาพต่าง ๆ ไปยังแกลเลอรีทางไกล
Comment[tr]=Resimleri uzak bir Galeriye aktarmak için bir araç
Comment[uk]=Інструмент для експорту зображення до віддаленого сервера Gallery
Comment[x-test]=xxA tool to export images to a remote Galleryxx
Comment[zh_CN]=一个将图像导出到远程 Gallery 的工具
Comment[zh_TW]=匯出影像到遠端 Gallery 的工具
Type=Service
Icon=kipi-gallery
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_galleryexport
X-KIPI-PluginCategories=Export
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Andrea Diamantini, adjam7@gmail.com
